@@ -128,7 +128,7 @@ INVALIDPARAMETER_CDNHOSTINVALIDPARAM = 'InvalidParameter.CdnHostInvalidParam'
 # Invalid domain name status.
 INVALIDPARAMETER_CDNHOSTINVALIDSTATUS = 'InvalidParameter.CdnHostInvalidStatus'
 
-# 
+# The domain name is too long.
 INVALIDPARAMETER_CDNHOSTTOOLONGHOST = 'InvalidParameter.CdnHostTooLongHost'
 
 # Internal API error. Please submit a ticket for troubleshooting.
@@ -293,12 +293,6 @@ RESOURCEINUSE_CDNHOSTEXISTS = 'ResourceInUse.CdnHostExists'
 # CDN resources are being operated.
 RESOURCEINUSE_CDNOPINPROGRESS = 'ResourceInUse.CdnOpInProgress'
 
-# The tag key does not exist.
-RESOURCENOTFOUND_CAMTAGKEYNOTEXIST = 'ResourceNotFound.CamTagKeyNotExist'
-
-# The tag does not exist.
-RESOURCENOTFOUND_CAMTAGNOTEXIST = 'ResourceNotFound.CamTagNotExist'
-
 # This domain name does not exist under the account. Please check and try again.
 RESOURCENOTFOUND_CDNHOSTNOTEXISTS = 'ResourceNotFound.CdnHostNotExists'
 
@@ -338,6 +332,9 @@ RESOURCEUNAVAILABLE_CDNHOSTEXISTSINTCB = 'ResourceUnavailable.CdnHostExistsInTcb
 # The domain name is locked.
 RESOURCEUNAVAILABLE_CDNHOSTISLOCKED = 'ResourceUnavailable.CdnHostIsLocked'
 
+# The domain name cannot be connected for being insecure or malicious.
+RESOURCEUNAVAILABLE_CDNHOSTISMALICIOUS = 'ResourceUnavailable.CdnHostIsMalicious'
+
 # Domain name is still in use.
 RESOURCEUNAVAILABLE_CDNHOSTISNOTOFFLINE = 'ResourceUnavailable.CdnHostIsNotOffline'
 
@@ -347,6 +344,9 @@ RESOURCEUNAVAILABLE_CDNHOSTISNOTONLINE = 'ResourceUnavailable.CdnHostIsNotOnline
 # The domain name does not have an ICP filing.
 RESOURCEUNAVAILABLE_CDNHOSTNOICP = 'ResourceUnavailable.CdnHostNoIcp'
 
+# The SCDN service is not activated. Please purchase or renew an SCDN packet and try again.
+RESOURCEUNAVAILABLE_SCDNUSERNOPACKAGE = 'ResourceUnavailable.ScdnUserNoPackage'
+
 # The sub-account is unauthorized to query full data.
 UNAUTHORIZEDOPERATION_CDNACCOUNTUNAUTHORIZED = 'UnauthorizedOperation.CdnAccountUnauthorized'
 
