@@ -23,9 +23,15 @@ INTERNALERROR = 'InternalError'
 # Invalid parameter.
 INVALIDPARAMETER = 'InvalidParameter'
 
+# Invalid parameter value.
+INVALIDPARAMETERVALUE = 'InvalidParameterValue'
+
 # The instance does not exist.
 INVALIDPARAMETERVALUE_INSTANCENOTEXIST = 'InvalidParameterValue.InstanceNotExist'
 
+# The parameter is required.
+INVALIDPARAMETERVALUE_NOTALLOWEDEMPTY = 'InvalidParameterValue.NotAllowedEmpty'
+
 # The parameter already exists.
 INVALIDPARAMETERVALUE_REPETITIONVALUE = 'InvalidParameterValue.RepetitionValue'
 
@@ -44,7 +50,13 @@ INVALIDPARAMETERVALUE_WRONGACTION = 'InvalidParameterValue.WrongAction'
 # The zone is not supported.
 INVALIDPARAMETERVALUE_ZONENOTSUPPORT = 'InvalidParameterValue.ZoneNotSupport'
 
-# 
+# Operation denied.
+OPERATIONDENIED = 'OperationDenied'
+
+# The number of requests exceeds the frequency limit.
+REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'
+
+# The resource is occupied.
 RESOURCEINUSE = 'ResourceInUse'
 
 # The resource is unavailable.
@@ -53,6 +65,12 @@ RESOURCEUNAVAILABLE = 'ResourceUnavailable'
 # Unauthorized operation.
 UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 
+# Unknown parameter error.
+UNKNOWNPARAMETER = 'UnknownParameter'
+
+# Unsupported operation.
+UNSUPPORTEDOPERATION = 'UnsupportedOperation'
+
 # The batch instance deletion limit is reached.
 UNSUPPORTEDOPERATION_BATCHDELINSTANCELIMIT = 'UnsupportedOperation.BatchDelInstanceLimit'
 
