@@ -62,9 +62,6 @@ FAILEDOPERATION_TASKDUPLICATE = 'FailedOperation.TaskDuplicate'
 # Operation failed: failed to upload file to COS.
 FAILEDOPERATION_UPLOADCOSFAIL = 'FailedOperation.UploadCosFail'
 
-# The service has been suspended.
-FAILEDOPERATION_USERSTATUSINAVLID = 'FailedOperation.UserStatusInavlid'
-
 # Internal error.
 INTERNALERROR = 'InternalError'
 
